# py-tewl

[![Release](https://img.shields.io/github/v/release/kristjanvalur/py-tewl)](https://img.shields.io/github/v/release/kristjanvalur/py-tewl)
[![Build status](https://img.shields.io/github/workflow/status/kristjanvalur/py-tewl/merge-to-main)](https://img.shields.io/github/workflow/status/kristjanvalur/py-tewl/merge-to-main)
[![Commit activity](https://img.shields.io/github/commit-activity/m/kristjanvalur/py-tewl)](https://img.shields.io/github/commit-activity/m/kristjanvalur/py-tewl)
[![Docs](https://img.shields.io/badge/docs-gh--pages-blue)](https://kristjanvalur.github.io/py-tewl/)
[![Code style with black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports with isort](https://img.shields.io/badge/%20imports-isort-%231674b1)](https://pycqa.github.io/isort/)
[![License](https://img.shields.io/github/license/kristjanvalur/py-tewl)](https://img.shields.io/github/license/kristjanvalur/py-tewl)

Kewl tools for Python

- **Github repository**: <https://github.com/kristjanvalur/py-tewl/>
- **Documentation** <https://kristjanvalur.github.io/py-tewl/>

## Releasing a new version

- Create an API Token on [Pypi](https://pypi.org/).
- Add the API Token to your projects secrets with the name `PYPI_TOKEN` by visiting 
[this page](https://github.com/kristjanvalur/py-tewl/settings/secrets/actions/new).
- Create a [new release](https://github.com/kristjanvalur/py-tewl/releases/new) on Github. 
Create a new tag in the form ``*.*.*``.

For more details, see [here](https://fpgmaas.github.io/cookiecutter-poetry/releasing.html).

---

Repository initiated with [fpgmaas/cookiecutter-poetry](https://github.com/fpgmaas/cookiecutter-poetry).